@@ -1,10 +1,10 @@
-/* $XFree86: xc/lib/font/stubs/stubs.h,v 1.4 2003/09/13 21:33:03 dawes Exp $ */
+/* $XFree86: xc/lib/font/stubs/stubs.h,v 1.5 2005/10/14 15:16:06 tsi Exp $ */
 
 /* This directory includes dummy entry for bdftopcf and mkfontdir */
 
 #include <stdio.h>
 #include "fntfilst.h"
-#include "font.h"
+#include <X11/fonts/font.h>
 
 
 #ifndef True
