@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Configure.c,v 3.85 2005/01/26 05:31:48 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Configure.c,v 3.94 2007/03/11 17:38:02 tsi Exp $ */
 /*
  * Copyright 2000-2002 by Alan Hourihane, Flint Mountain, North Wales.
  *
@@ -76,8 +76,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include "X.h"
-#include "Xmd.h"
+#include <X11/X.h>
+#include <X11/Xmd.h>
 #include "os.h"
 #ifdef XFree86LOADER
 #include "loaderProcs.h"
@@ -89,9 +89,8 @@
 #define IN_XSERVER
 #include "xf86Parser.h"
 #include "xf86tokens.h"
-#include "vbe.h"
 #include "xf86DDC.h"
-#if defined(__sparc__) && !defined(__OpenBSD__)
+#if defined(__sparc__)
 #include "xf86Bus.h"
 #include "xf86Sbus.h"
 #endif
@@ -100,7 +99,7 @@
 typedef struct _DevToConfig {
     GDevRec GDev;
     pciVideoPtr pVideo;
-#if defined(__sparc__) && !defined(__OpenBSD__)
+#if defined(__sparc__)
     sbusDevicePtr sVideo;
 #endif
     int iDriver;
@@ -111,7 +110,7 @@ static int nDevToConfig = 0, CurrentDriver;
 
 xf86MonPtr ConfiguredMonitor;
 Bool xf86DoConfigurePass1 = TRUE;
-Bool foundMouse = FALSE;
+static Bool foundMouse = FALSE;
 
 #if defined(__UNIXOS2__)
 #define DFLT_MOUSE_DEV "mouse$"
@@ -171,7 +170,7 @@ xf86AddBusDeviceToConfigure(const char *driver, BusType bus, void *busData, int
 	    if (!DevToConfig[i].pVideo)
 		return NULL;
 	break;
-#if defined(__sparc__) && !defined(__OpenBSD__)
+#if defined(__sparc__)
     case BUS_SBUS:
 	for (i = 0;  i < nDevToConfig;  i++)
 	    if (DevToConfig[i].sVideo &&
@@ -250,7 +249,7 @@ xf86AddBusDeviceToConfigure(const char *driver, BusType bus, void *busData, int
 	NewDevice.GDev.identifier = "ISA Adapter";
 	NewDevice.GDev.busID = "ISA";
 	break;
-#if defined(__sparc__) && !defined(__OpenBSD__)
+#if defined(__sparc__)
     case BUS_SBUS: {
 	char *promPath = NULL;
 	NewDevice.sVideo = (sbusDevicePtr) busData;
@@ -307,7 +306,30 @@ configureInputSection (void)
     configPrologue(XF86ConfInputPtr)
 
     ptr->inp_identifier = "Keyboard0";
+#if defined(WSCONS_SUPPORT)
+    /* check for /dev/wskbd */
+    {
+#if defined(__NetBSD__)
+# define WSKBD "/dev/wskbd"
+#elif defined(__OpenBSD__)
+# define WSKBD "/dev/wskbd0"
+#endif
+	int fd = open(WSKBD, 0);
+	if (fd > 0) {
+	    close(fd);
+	    ptr->inp_driver = "kbd";
+	    ptr->inp_option_lst = 
+		xf86addNewOption(ptr->inp_option_lst, "Protocol", "wskbd");
+	    ptr->inp_option_lst = 
+		xf86addNewOption(ptr->inp_option_lst, "Device", WSKBD);
+        } else {
+    	    /* no /dev/wskbd - fall back to legacy driver */
+            ptr->inp_driver = "keyboard";
+	}
+    }
+#else
     ptr->inp_driver = "keyboard";
+#endif
     ptr->list.next = NULL;
 
     /* Crude mechanism to auto-detect mouse (os dependent) */
@@ -410,7 +432,7 @@ configureScreenSection (int screennum)
 }
 
 static const char* 
-optionTypeToSting(OptionValueType type)
+optionTypeToString(OptionValueType type)
 {
     switch (type) {
     case OPTV_NONE:
@@ -485,7 +507,7 @@ configureDeviceSection (int screennum)
 		const char *prefix = "        #Option     ";
 		const char *middle = " \t# ";
 		const char *suffix = "\n";
-		const char *opttype = optionTypeToSting(p->type);
+		const char *opttype = optionTypeToString(p->type);
 		char *optname;
 		int len = strlen(ptr->dev_comment) + strlen(prefix) +
 			  strlen(middle) + strlen(suffix) + 1;
@@ -691,10 +713,8 @@ configureFilesSection (void)
 {
     configPrologue(XF86ConfFilesPtr)
 
-#ifdef XFree86LOADER
    if (xf86FilePaths->modulePath)
        ptr->file_modulepath = strdup(xf86FilePaths->modulePath);
-#endif
    if (defaultFontPath)
        ptr->file_fontpath = strdup(defaultFontPath);
    if (rgbPath)
@@ -880,7 +900,7 @@ DoConfigure()
 #ifdef __UNIXOS2__
 #define PATH_MAX 2048
 #endif
-#if defined(__SCO__)
+#ifndef PATH_MAX
 #define PATH_MAX 1024
 #endif
         const char* configfile = XF86CONFIGFILE".new";
@@ -913,26 +933,26 @@ DoConfigure()
 	goto bail;
     }
 
-    xf86DoConfigurePass1 = FALSE;
-    
-    dev2screen = xnfcalloc(1,xf86NumDrivers*sizeof(int));
+    dev2screen = xnfcalloc(1, nDevToConfig * sizeof(int));
 
     {
-	Bool *driverProbed = xnfcalloc(1,xf86NumDrivers*sizeof(Bool));
+	Bool *driverProbed = xnfcalloc(1, xf86NumDrivers * sizeof(Bool));
+	int nextPrimary = 0;
+
 	for (screennum = 0;  screennum < nDevToConfig;  screennum++) {
-	    int k,l,n,oldNumScreens;
+	    int k, l, n, oldNumScreens;
 
 	    i = DevToConfig[screennum].iDriver;
 
-	    if (driverProbed[i]) continue;
+	    if (driverProbed[i])
+		continue;
 	    driverProbed[i] = TRUE;
 	    
 	    oldNumScreens = xf86NumScreens;
 
 	    (*xf86DriverList[i]->Probe)(xf86DriverList[i], 0);
 
-	    /* reorder */
-	    k = screennum > 0 ? screennum : 1;
+	    /* Possibly reorder */
 	    for (l = oldNumScreens; l < xf86NumScreens; l++) {
 	        /* is screen primary? */
 	        Bool primary = FALSE;
@@ -943,22 +963,19 @@ DoConfigure()
 			break;
 		    }
 		}
-		if (primary) continue;
-		/* not primary: assign it to next device of same driver */
-		/* 
-		 * NOTE: we assume that devices in DevToConfig 
-		 * and xf86Screens[] have the same order except
-		 * for the primary device which always comes first.
-		 */
-		for (; k < nDevToConfig; k++) {
-		    if (DevToConfig[k].iDriver == i) {
-		        dev2screen[k++] = l;
-			break;
-		    }
+
+		if (primary) {
+		    for (k = l; --k >= nextPrimary; )
+			dev2screen[k + 1] = dev2screen[k];
+		    dev2screen[nextPrimary++] = l;
+		} else {
+		    dev2screen[l] = l;
 		}
 	    }
-	    xf86SetPciVideo(NULL,NONE);
+
+	    xf86SetPciVideo(NULL, NONE);
 	}
+
 	xfree(driverProbed);
     }
     
@@ -1031,6 +1048,7 @@ DoConfigure()
     ErrorF("To test the server, run 'XFree86 -xf86config %s'\n\n", filename);
 
 bail:
+    CloseWellKnownConnections();
     OsCleanup(TRUE);
     AbortDDX();
     fflush(stderr);
