@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/chips/ct_video.c,v 1.17 2003/11/10 18:22:19 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/chips/ct_video.c,v 1.19 2005/10/14 15:16:38 tsi Exp $ */
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
@@ -11,9 +11,8 @@
 #include "regionstr.h"
 
 #include "ct_driver.h"
-#include "Xv.h"
+#include <X11/extensions/Xv.h>
 #include "xaa.h"
-#include "xaalocal.h"
 #include "dixstruct.h"
 #include "fourcc.h"
 
