@@ -23,7 +23,7 @@
  *
  *
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/input/acecad/acecad.c,v 1.5 2003/11/05 20:56:29 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/input/acecad/acecad.c,v 1.6 2006/03/16 16:50:25 dawes Exp $ */
 
 #define _ACECAD_C_
 /*****************************************************************************
@@ -106,7 +106,7 @@ XF86ModuleData acecadModuleData = { &VersionRec, SetupProc, TearDownProc};
  ****************************************************************************/
 
 static pointer
-SetupProc(	pointer module,
+SetupProc(	ModuleDescPtr module,
 		pointer options,
 		int *errmaj,
 		int *errmin )
