@@ -1,5 +1,5 @@
 /*
- * $XFree86: xc/programs/Xserver/render/picture.c,v 1.31 2004/06/30 20:21:46 martin Exp $
+ * $XFree86: xc/programs/Xserver/render/picture.c,v 1.32 2006/02/19 15:51:32 tsi Exp $
  *
  * Copyright  2000 SuSE, Inc.
  *
@@ -614,7 +614,7 @@ PictureInit (ScreenPtr pScreen, PictFormatPtr formats, int nformats)
 	    return FALSE;
 	PictureWindowPrivateIndex = AllocateWindowPrivateIndex();
 	PictureGeneration = serverGeneration;
-#ifdef XResExtension
+#ifdef XRES
 	RegisterResourceName (PictureType, "PICTURE");
 	RegisterResourceName (PictFormatType, "PICTFORMAT");
 	RegisterResourceName (GlyphSetType, "GLYPHSET");
