@@ -1,5 +1,4 @@
-/* $XConsortium: get_load.c /main/37 1996/03/09 09:38:04 kaleb $ */
-/* $XFree86: xc/programs/xload/get_load.c,v 1.21 2003/12/19 02:05:40 dawes Exp $ */
+/* $XFree86: xc/programs/xload/get_load.c,v 1.24 2007/04/03 00:21:14 tsi Exp $ */
 /*
 
 Copyright (c) 1989  X Consortium
@@ -154,9 +153,7 @@ struct lavnum {
 extern long lseek();
 #endif
 
-static void xload_error(
-char *, char *
-);
+void xload_error(char *, char *);
 
 
 #ifdef apollo
@@ -467,7 +464,7 @@ void GetLoadPoint( w, closure, call_data )
     double *loadavg = (double *)call_data;
 
     struct host_load_info load_data;
-    int host_count;
+    unsigned int host_count;
     kern_return_t kr;
 
     host_count = sizeof(load_data)/sizeof(integer_t);
@@ -1071,7 +1068,7 @@ void GetLoadPoint( w, closure, call_data )
 #endif /* KVM_ROUTINES else */
 #endif /* SYSV && i386 else */
 
-static void xload_error(str1, str2)
+void xload_error(str1, str2)
 char *str1, *str2;
 {
     (void) fprintf(stderr,"xload: %s %s\n", str1, str2);
